(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/platform-browser'), require('@angular/router'), require('rxjs/add/operator/filter'), require('rxjs/add/operator/map')) :
	typeof define === 'function' && define.amd ? define('ng2-meta', ['exports', '@angular/core', '@angular/platform-browser', '@angular/router', 'rxjs/add/operator/filter', 'rxjs/add/operator/map'], factory) :
	(factory((global['ng2-meta'] = {}),global.ng.core,global.ng.platformBrowser,global.ng.router));
}(this, (function (exports,core,platformBrowser,router) { 'use strict';

var META_CONFIG_TOKEN = new core.InjectionToken('meta config');
var META_GUARD_IDENTIFIER = 'MetaGuard';
var isDefined = function (val) { return typeof val !== 'undefined'; };
var MetaService = /** @class */ (function () {
    function MetaService(router$$1, meta, titleService, activatedRoute, metaConfig) {
        this.router = router$$1;
        this.meta = meta;
        this.titleService = titleService;
        this.activatedRoute = activatedRoute;
        this.metaConfig = metaConfig;
        this._warnMissingGuard();
    }
    MetaService.prototype.setTitle = function (title, titleSuffix) {
        var titleContent = isDefined(title) ? title : (this.metaConfig.defaults['title'] || '');
        if (this.metaConfig.useTitleSuffix) {
            titleContent += isDefined(titleSuffix) ? titleSuffix : (this.metaConfig.defaults['titleSuffix'] || '');
        }
        this._updateMetaTag('title', titleContent);
        this._updateMetaTag('og:title', titleContent);
        this.titleService.setTitle(titleContent);
        return this;
    };
    MetaService.prototype.setTag = function (tag, value) {
        if (tag === 'title' || tag === 'titleSuffix') {
            throw new Error("Attempt to set " + tag + " through 'setTag': 'title' and 'titleSuffix' are reserved tag names.\n      Please use 'MetaService.setTitle' instead");
        }
        var content = isDefined(value) ? value : (this.metaConfig.defaults[tag] || '');
        this._updateMetaTag(tag, content);
        if (tag === 'description') {
            this._updateMetaTag('og:description', content);
        }
        return this;
    };
    MetaService.prototype._updateMetaTag = function (tag, value) {
        var prop = 'name';
        if (tag.startsWith("og:")) {
            prop = 'property';
        }
        this.meta.updateTag((_a = {}, _a[prop] = tag, _a.content = value, _a));
        var _a;
    };
    MetaService.prototype._warnMissingGuard = function () {
        if (isDefined(this.metaConfig.warnMissingGuard) && !this.metaConfig.warnMissingGuard) {
            return;
        }
        var hasDefaultMeta = !!Object.keys(this.metaConfig.defaults).length;
        var hasMetaGuardInArr = function (it) { return (it && it.IDENTIFIER === META_GUARD_IDENTIFIER); };
        var hasShownWarnings = false;
        this.router.config.forEach(function (route) {
            var hasRouteMeta = route.data && route.data["meta"];
            var showWarning = !isDefined(route.redirectTo)
                && (hasDefaultMeta || hasRouteMeta)
                && !(route.canActivate || []).some(hasMetaGuardInArr);
            if (showWarning) {
                console.warn("Route with path \"" + route.path + "\" has " + (hasRouteMeta ? '' : 'default ') + "meta tags, but does not use MetaGuard. Please add MetaGuard to the canActivate array in your route configuration");
                hasShownWarnings = true;
            }
        });
        if (hasShownWarnings) {
            console.warn("To disable these warnings, set metaConfig.warnMissingGuard: false in your ng2-meta MetaConfig passed to MetaModule.forRoot()");
        }
    };
    return MetaService;
}());
MetaService.decorators = [
    { type: core.Injectable },
];
MetaService.ctorParameters = function () { return [
    { type: router.Router, },
    { type: platformBrowser.Meta, },
    { type: platformBrowser.Title, },
    { type: router.ActivatedRoute, },
    { type: undefined, decorators: [{ type: core.Inject, args: [META_CONFIG_TOKEN,] },] },
]; };
var DEFAULT_META_CONFIG = {
    useTitleSuffix: false,
    warnMissingGuard: true,
    defaults: {}
};
var MetaGuard = /** @class */ (function () {
    function MetaGuard(router$$1, metaService, metaConfig) {
        this.router = router$$1;
        this.metaService = metaService;
        this.metaConfig = metaConfig;
    }
    MetaGuard.prototype.canActivate = function (route, state) {
        this._processRouteMetaTags(route.data && route.data["meta"]);
        return true;
    };
    MetaGuard.prototype._processRouteMetaTags = function (meta) {
        var _this = this;
        if (meta === void 0) { meta = {}; }
        if (meta.disableUpdate) {
            return;
        }
        this.metaService.setTitle(meta.title, meta.titleSuffix);
        Object.keys(meta).forEach(function (key) {
            if (key === 'title' || key === 'titleSuffix') {
                return;
            }
            _this.metaService.setTag(key, meta[key]);
        });
        Object.keys(this.metaConfig.defaults).forEach(function (key) {
            if (key in meta || key === 'title' || key === 'titleSuffix') {
                return;
            }
            _this.metaService.setTag(key, _this.metaConfig.defaults[key]);
        });
    };
    return MetaGuard;
}());
MetaGuard.IDENTIFIER = META_GUARD_IDENTIFIER;
MetaGuard.decorators = [
    { type: core.Injectable },
];
MetaGuard.ctorParameters = function () { return [
    { type: router.Router, },
    { type: MetaService, },
    { type: undefined, decorators: [{ type: core.Inject, args: [META_CONFIG_TOKEN,] },] },
]; };
var MetaModule = /** @class */ (function () {
    function MetaModule(parentModule) {
        if (parentModule) {
            throw new Error('MetaModule is already loaded. Import it in the AppModule only');
        }
    }
    MetaModule.forRoot = function (metaConfig) {
        if (metaConfig === void 0) { metaConfig = DEFAULT_META_CONFIG; }
        return {
            ngModule: MetaModule,
            providers: [
                { provide: META_CONFIG_TOKEN, useValue: metaConfig },
                MetaGuard,
                MetaService
            ]
        };
    };
    return MetaModule;
}());
MetaModule.decorators = [
    { type: core.NgModule, args: [{
                imports: [
                    router.RouterModule
                ]
            },] },
];
MetaModule.ctorParameters = function () { return [
    { type: MetaModule, decorators: [{ type: core.Optional }, { type: core.SkipSelf },] },
]; };

exports.MetaService = MetaService;
exports.MetaModule = MetaModule;
exports.MetaGuard = MetaGuard;
exports.ɵa = DEFAULT_META_CONFIG;
exports.ɵb = META_CONFIG_TOKEN;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ng2-meta.umd.js.map
